package ZipTie::Adapters::Cisco::NGIPS;

use strict;
use warnings;
use 5.010_000;

use ZipTie::Adapters::BaseAdapter;
use ZipTie::Adapters::Cisco::NGIPS::AutoLogin qw(login);
use ZipTie::Adapters::Cisco::NGIPS::Parsers qw(parse_system parse_chassis parse_interfaces get_vuln_ids parse_object_groups parse_filters print_interfaces parse_static_routes);
use ZipTie::Adapters::Cisco::NGIPS::Disconnect qw(disconnect);
use ZipTie::Adapters::Cisco::NGIPS::Utils qw(get_responses);
use ZipTie::Adapters::Utils qw(get_model_filehandle close_model_filehandle);
use ZipTie::Model::XmlPrint;
use ZipTie::CLIProtocolFactory;
use ZipTie::ConnectionPath;
use ZipTie::Logger;

use Exporter qw(import);

our @ISA = qw(ZipTie::Adapters::BaseAdapter);
my $LOGGER = ZipTie::Logger::get_logger();

sub backup{
	my ($package_name, $backup_doc) = @_;

	# Parse the backup operation XML document and extract a ZipTie::ConnectionPath object from it
	my ($connection_path) = ZipTie::Typer::translate_document($backup_doc, 'connectionPath');

	# Connect to the device and capture the ZipTie::CLIProtocol that is created as a result of the connection.
	# Also be sure to capture the device prompt that is returned as a result of a successful connection.
	my $cli_protocol = ZipTie::CLIProtocolFactory::create($connection_path);	
	my $device_prompt_regex = login($cli_protocol, $connection_path);

	# Store the found prompt as "prompt" on the specified CLI protocol.
	$cli_protocol->set_prompt_by_name('prompt', $device_prompt_regex);

	# Get the model set up
	my $filehandle = get_model_filehandle('NGIPS', $connection_path->get_ip_address());
	my $printer = ZipTie::Model::XmlPrint->new($filehandle, 'common');
	$printer->open_model();

	# Get the command responses and feed into the parser
	my $responses = get_responses($cli_protocol, $device_prompt_regex, $connection_path);
	$responses->{os_vendor} = 'Cisco';
	$responses->{os_name} = 'Firepower';
	$responses->{os_type} = 'Firepower';
	parse_system($responses, $printer);
	parse_chassis($responses, $printer);
	parse_interfaces($responses, $printer);
	get_vuln_ids($responses, $printer);
	parse_object_groups($responses, $printer);
	parse_filters($responses, $printer);
	print_interfaces($responses, $printer);
	parse_static_routes($responses, $printer);

	# Tidy up. Job done.
	$printer->close_model();
	close_model_filehandle($filehandle);
	disconnect($cli_protocol);
}

1;
