package ZipTie::Adapters::Juniper::JUNOS::SecurityApps;

use strict;
use warnings;
use 5.010_000;

use Exporter 'import';
our @EXPORT_OK = '$securityApps';

my $securityApps = {
	# ICMP-replated
	'ICMP-ANY'                           => [ { protocol => 'icmp' }, ],
	'ICMP-ADDRESS-MASK'                  => [ { protocol => 'icmp' }, ],
	'ICMP-DEST-UNREACH'                  => [ { protocol => 'icmp' }, ],
	'ICMP Fragment Needed'               => [ { protocol => 'icmp' }, ],
	'ICMP FragmentReassembly'            => [ { protocol => 'icmp' }, ],
	'ICMP-HOST-UNREACH'                  => [ { protocol => 'icmp' }, ],
	'ICMP-INFO'                          => [ { protocol => 'icmp' }, ],
	'ICMP-PARAMETER-PROBLEM'             => [ { protocol => 'icmp' }, ],
	'ICMP-PORT-UNREACH'                  => [ { protocol => 'icmp' }, ],
	'ICMP-PROTOCOL-UNREACH'              => [ { protocol => 'icmp' }, ],
	'ICMP-REDIRECT'                      => [ { protocol => 'icmp' }, ],
	'ICMP-REDIRECT-HOST'                 => [ { protocol => 'icmp' }, ],
	'ICMP-REDIRECT-TOS-HOST'             => [ { protocol => 'icmp' }, ],
	'ICMP-REDIRECT-TOS-NET'              => [ { protocol => 'icmp' }, ],
	'ICMP-SOURCE-QUENCH'                 => [ { protocol => 'icmp' }, ],
	'ICMP-SOURCE-ROUTE-FAIL'             => [ { protocol => 'icmp' }, ],
	'ICMP-TIME-EXCEEDED'                 => [ { protocol => 'icmp' }, ],
	'ICMP-TIMESTAMP'                     => [ { protocol => 'icmp' }, ],
	'ICMP-ECHO-FRAGMENT-ASSEMBLY-EXPIRE' => [ { protocol => 'icmp' }, ],
	'Traceroute'                         => [ { protocol => 'icmp' }, ],

	# Internet related
	'AOL' => [
		{
			portRange =>
			  { portStart => 5190, portEnd => 5193, protocol => 'tcp', },
		},
	],
	'DHCP relay' => [
		{
			portExpression =>
			  { operator => 'eq', port => 67, protocol => 'udp', },
		},
	],
	'DHCP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 67, protocol => 'udp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 68, protocol => 'udp', },
		},
	],
	'DNS' => [
		{
			portExpression =>
			  { operator => 'eq', port => 53, protocol => 'udp', },
		},
	],
	'FTP-Get' => [
		{
			portExpression =>
			  { operator => 'eq', port => 20, protocol => 'tcp', },
		},
	],
	'FTP-Put' => [
		{
			portExpression =>
			  { operator => 'eq', port => 21, protocol => 'tcp', },
		},
	],
	'Gopher' => [
		{
			portExpression =>
			  { operator => 'eq', port => 70, protocol => 'tcp', },
		},
	],
	'HTTP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 8080, protocol => 'tcp', },
		},
	],
	'HTTPS' => [
		{
			portExpression =>
			  { operator => 'eq', port => 443, protocol => 'tcp', },
		},
	],
	'IRC' => [
		{
			portRange =>
			  { portStart => 6665, portEnd => 6669, protocol => 'tcp', },
		},
	],
	'LDAP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 389, protocol => 'tcp', },
		},
	],
	'TFTP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 69, protocol => 'udp', },
		},
	],

	# M$ related, many missing because they are based of off content, not ports
	'MS-RPC-EPM' => [
		{
			portExpression =>
			  { operator => 'eq', port => 135, protocol => 'tcp' },
		},
	],

	# Dynamic routing related
	'RIP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 520, protocol => 'udp' },
		},
	],
	'OSPF' => [ { protocol => 'osfp' } ],

	# streaming related
	'H.323' => [
		{
			portExpression =>
			  { operator => 'eq', port => 1720, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 1503, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 389, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 522, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 1731, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 1719, protocol => 'udp', },
		},
	],
	'NetMeeting' => [
		{
			portExpression =>
			  { operator => 'eq', port => 1720, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 1503, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 389, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 522, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 1731, protocol => 'tcp', },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 1719, protocol => 'udp', },
		},
	],
	'Real Media' => [
		{
			portExpression =>
			  { operator => 'eq', port => 7070, protocol => 'tcp' },
		},
	],
	'RTSP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 554, protocol => 'tcp' },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 554, protocol => 'udp' },
		},
	],
	'SIP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 5056, protocol => 'udp' },
		},
	],
	'VDO Live' => [
		{
			portRange =>
			  { portStart => 7000, portEnd => 7010, protocol => 'tcp', },
		},
	],

	# SUN RPC related are all left out because they are protocol based.
	# IPSEC/Tunnel related
	'IKE' => [
		{
			portExpression =>
			  { operator => 'eq', port => 500, protocol => 'udp' },
		},
	],
	'L2TP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 1723, protocol => 'tcp' },
		},
	],
	'PPTP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 1723, protocol => 'tcp' },
		},
	],

	# IM related
	'Gnutella' => [
		{
			portExpression =>
			  { operator => 'eq', port => 6346, protocol => 'tcp' },
		},
	],
	'MSN' => [
		{
			portExpression =>
			  { operator => 'eq', port => 1863, protocol => 'tcp' },
		},
	],
	'NNTP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 119, protocol => 'tcp' },
		},
	],
	'SMB' => [
		{
			portExpression =>
			  { operator => 'eq', port => 445, protocol => 'tcp' },
		},
	],
	'YMSG' => [
		{
			portExpression =>
			  { operator => 'eq', port => 5010, protocol => 'tcp' },
		},
	],

	# management related
	'NBNAME' => [
		{
			portExpression =>
			  { operator => 'eq', port => 137, protocol => 'udp' },
		},
	],
	'NDBDS' => [
		{
			portExpression =>
			  { operator => 'eq', port => 138, protocol => 'udp' },
		},
	],
	'NTP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 123, protocol => 'udp' },
		},
	],
	'RLOGIN' => [
		{
			portExpression =>
			  { operator => 'eq', port => 513, protocol => 'tcp' },
		},
	],
	'RSH' => [
		{
			portExpression =>
			  { operator => 'eq', port => 514, protocol => 'tcp' },
		},
	],
	'SNMP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 161, protocol => 'udp' },
		},
	],
	'SQL*Net V1' => [
		{
			portExpression =>
			  { operator => 'eq', port => 66, protocol => 'tcp' },
		},
	],
	'SQL*Net V2' => [
		{
			portExpression =>
			  { operator => 'eq', port => 66, protocol => 'tcp' },
		},
	],
	'MSSQL' => [
		{
			portExpression =>
			  { operator => 'eq', port => 1433, protocol => 'tcp' },
		},
	],
	'SSH' => [
		{
			portExpression =>
			  { operator => 'eq', port => 22, protocol => 'tcp' },
		},
	],
	'Talk' => [
		{
			portRange =>
			  { portStart => 517, portEnd => 518, protocol => 'tcp', },
		},
	],
	'Telnet' => [
		{
			portExpression =>
			  { operator => 'eq', port => 23, protocol => 'tcp' },
		},
	],

	# Mail related
	'IMAP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 143, protocol => 'tcp' },
		},
	],
	'SMTP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 25, protocol => 'tcp' },
		},
	],
	'POP3' => [
		{
			portExpression =>
			  { operator => 'eq', port => 110, protocol => 'tcp' },
		},
	],

	# UNIX related
	'FINGER' => [
		{
			portExpression =>
			  { operator => 'eq', port => 79, protocol => 'tcp' },
		},
	],
	'UUCP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 117, protocol => 'tcp' },
		},
	],

	# Misc services
	'CHARGEN' => [
		{
			portExpression =>
			  { operator => 'eq', port => 19, protocol => 'tcp' },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 19, protocol => 'udp' },
		},
	],
	'DISCARD' => [
		{
			portExpression =>
			  { operator => 'eq', port => 9, protocol => 'tcp' },
		},
		{
			portExpression =>
			  { operator => 'eq', port => 9, protocol => 'udp' },
		},
	],
	'LPR' => [
		{
			portExpression =>
			  { operator => 'eq', port => 515, protocol => 'tcp' },
		},
	],
	'RADIUS' => [
		{
			portExpression =>
			  { operator => 'eq', port => 1812, protocol => 'tcp' },
		},
	],
	'SQLMON' => [
		{
			portExpression =>
			  { operator => 'eq', port => 1434, protocol => 'udp' },
		},
	],
	'VNC' => [
		{
			portExpression =>
			  { operator => 'eq', port => 5800, protocol => 'tcp' },
		},
	],
	'WHOIS' => [
		{
			portExpression =>
			  { operator => 'eq', port => 43, protocol => 'tcp' },
		},
	],
	'SCCP' => [
		{
			portExpression =>
			  { operator => 'eq', port => 2000, protocol => 'tcp' },
		},
	],
};

1;
